# coding=utf-8

import logging

from django.test import TestCase

from web.importer import CsvSubjectImportReader
from web.tests.functions import get_resource_path

logger = logging.getLogger(__name__)


class TestCsvReader(TestCase):

    def test_load_data(self):
        filename = get_resource_path('import.csv')
        study_subjects = CsvSubjectImportReader().load_data(filename)
        self.assertEqual(1, len(study_subjects))
        study_subject = study_subjects[0]
        self.assertEqual("Piotr", study_subject.subject.first_name)
        self.assertEqual("Gawron", study_subject.subject.last_name)
        self.assertEqual("Cov-000001", study_subject.screening_number)
        self.assertEqual("Cov-000001", study_subject.nd_number)

        self.assertEqual(1, study_subject.subject.date_born.day)
        self.assertEqual(2, study_subject.subject.date_born.month)
        self.assertEqual(2020, study_subject.subject.date_born.year)

        self.assertIsNotNone(study_subject.study)

    def test_load_problematic_dates(self):
        filename = get_resource_path('import_date_of_birth.csv')
        study_subjects = CsvSubjectImportReader().load_data(filename)
        self.assertEqual(3, len(study_subjects))
        self.assertIsNone(study_subjects[0].subject.date_born)
        self.assertIsNone(study_subjects[1].subject.date_born)
        self.assertIsNone(study_subjects[2].subject.date_born)
